"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.detectReactQueryImports = void 0;
function detectReactQueryImports(create) {
    return (context, optionsWithDefault) => {
        const reactQueryImportSpecifiers = [];
        const helpers = {
            isReactQueryImport(node) {
                return !!reactQueryImportSpecifiers.find((specifier) => {
                    if (specifier.type === 'ImportSpecifier') {
                        return node.name === specifier.local.name;
                    }
                });
            },
        };
        const detectionInstructions = {
            ImportDeclaration(node) {
                if (node.specifiers.length > 0 &&
                    node.importKind === 'value' &&
                    node.source.value === 'react-query') {
                    reactQueryImportSpecifiers.push(...node.specifiers);
                }
            },
        };
        // Call original rule definition
        const ruleInstructions = create(context, optionsWithDefault, helpers);
        const enhancedRuleInstructions = {};
        const allKeys = new Set(Object.keys(detectionInstructions).concat(Object.keys(ruleInstructions)));
        // Iterate over ALL instructions keys so we can override original rule instructions
        // to prevent their execution if conditions to report errors are not met.
        allKeys.forEach((instruction) => {
            enhancedRuleInstructions[instruction] = (node) => {
                var _a, _b;
                if (instruction in detectionInstructions) {
                    (_a = detectionInstructions[instruction]) === null || _a === void 0 ? void 0 : _a.call(detectionInstructions, node);
                }
                // TODO: canReportErrors()
                if (ruleInstructions[instruction]) {
                    return (_b = ruleInstructions[instruction]) === null || _b === void 0 ? void 0 : _b.call(ruleInstructions, node);
                }
                return undefined;
            };
        });
        return enhancedRuleInstructions;
    };
}
exports.detectReactQueryImports = detectReactQueryImports;
